@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from __future__ import annotations
 
 import logging
@@ -14,7 +13,7 @@ from contextlib import contextmanager
 from datetime import datetime
 from functools import partial
 from pathlib import Path
-from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
+from typing import Any, Iterable
 
 import requests
 
@@ -33,7 +32,6 @@ class ExtraLine(list):
 
 
 class DepAnalyzer(ABC):  # pylint: disable=too-many-instance-attributes
-
     project_root: Path
 
     analyzer_name: str
@@ -53,18 +51,22 @@ class DepAnalyzer(ABC):  # pylint: disable=too-many-instance-attributes
             self._additional_packages_to_ignore = {}
         else:
             self._additional_packages_to_ignore = additional_packages_to_ignore
-        self._extra_lines: Optional[List[ExtraLine]] = None
+        self._extra_lines: list[ExtraLine] | None = None
         self._exported_reqs = None
-        self._reqs: Optional[Dict[Any, PackageInfo]] = None
+        self._reqs: dict[Any, PackageInfo] | None = None
         self._pkgs_to_ignore_dict = None
         if project_root is None:
             self.project_root = Path.cwd()
         else:
             self.project_root = Path(project_root)
 
-        self._pip = shutil.which("pip")
-        if self._pip is None:
-            raise CommandNotFoundError("pip not found, please install and add to PATH")
+        # self._pip = shutil.which("pip")
+        # print(subprocess.check_output("which pip3", shell=True))
+        # self._pip = "/home/sullid2/.pyenv/versions/3.9.12/bin/pip3.9"
+        # print(self._pip)
+
+        # if self._pip is None:
+        #     raise CommandNotFoundError("pip not found, please install and add to PATH")
         self.python_version = python_version
         self.architecture = architecture
         self.region = region
@@ -88,15 +90,15 @@ class DepAnalyzer(ABC):  # pylint: disable=too-many-instance-attributes
 
     # region abstract methods
     @abstractmethod
-    def _get_requirements(self) -> Iterable[Union[PackageInfo, ExtraLine]]:
+    def _get_requirements(self) -> Iterable[PackageInfo | ExtraLine]:
         pass
 
     @abstractmethod
-    def _update_dependency_file(self, pkgs_to_add: Dict[str, PackageInfo]):
+    def _update_dependency_file(self, pkgs_to_add: dict[str, PackageInfo]):
         pass
 
     @abstractmethod
-    def direct_dependencies(self) -> Dict[str, str]:
+    def direct_dependencies(self) -> dict[str, str]:
         pass
 
     # endregion
@@ -129,7 +131,7 @@ class DepAnalyzer(ABC):  # pylint: disable=too-many-instance-attributes
         return {k: PackageInfo(k, v, f"{k}=={v}") for k, v in self.pkgs_to_ignore_dict.items()}
 
     @property
-    def requirements(self) -> Dict[str, PackageInfo]:
+    def requirements(self) -> dict[str, PackageInfo]:
         if self._reqs is None:
             self.log.warning("Exporting requirements")
             reqs = self.update_dependency_file()
@@ -214,12 +216,12 @@ class DepAnalyzer(ABC):  # pylint: disable=too-many-instance-attributes
     # endregion
 
     # region public methods
-    def get_requirements(self) -> Iterable[Union[PackageInfo, ExtraLine]]:
+    def get_requirements(self) -> Iterable[PackageInfo | ExtraLine]:
         self.log.info("Getting requirements info using %s", self.analyzer_name)
         return self._get_requirements()
 
     @classmethod
-    def process_requirements(cls, requirements: Iterable[str]) -> Iterable[Union[PackageInfo, ExtraLine]]:
+    def process_requirements(cls, requirements: Iterable[str]) -> Iterable[PackageInfo | ExtraLine]:
         for line in requirements:
             if line.startswith("#") or line.strip() == "":
                 continue
@@ -234,7 +236,7 @@ class DepAnalyzer(ABC):  # pylint: disable=too-many-instance-attributes
 
     def run_command(
         self, *args, return_state=False, quiet=False, prefix=None, context=None
-    ) -> Union[bool, Tuple[str, str]]:
+    ) -> bool | tuple[str, str]:
         if prefix is None:
             prefix = Path(args[0]).name
         self.log.debug("Running command: %s", args)
@@ -287,7 +289,10 @@ class DepAnalyzer(ABC):  # pylint: disable=too-many-instance-attributes
             if isinstance(pkg, ExtraLine):
                 continue
             pkg_name, pkg_version, _ = pkg
-            if pkg_name in self.pkgs_to_ignore_dict and pkg_version != self.pkgs_to_ignore_dict[pkg_name]:
+            if (
+                pkg_name in self.pkgs_to_ignore_dict
+                and pkg_version != self.pkgs_to_ignore_dict[pkg_name]
+            ):
                 self.log.warning(
                     "%s is currently %s but should be %s",
                     pkg_name,
@@ -307,7 +312,10 @@ class DepAnalyzer(ABC):  # pylint: disable=too-many-instance-attributes
         if self._exported_reqs is None:
             output = []
             for pkg_name, pkg_version, pkg_spec in self.requirements.values():
-                if self.pkgs_to_ignore_dict.get(strip_extras.sub("", pkg_name), None) == pkg_version:
+                if (
+                    self.pkgs_to_ignore_dict.get(strip_extras.sub("", pkg_name), None)
+                    == pkg_version
+                ):
                     self.log.warning(
                         "Ignoring %s as it should be in the AWS Lambda Environment already",
                         pkg_spec.strip().split(";")[0],
@@ -324,7 +332,7 @@ class DepAnalyzer(ABC):  # pylint: disable=too-many-instance-attributes
         return ret
 
     def run_pip(self, *args, return_state=False, quiet=False, context=None):
-        self.run_command(self._pip, *args, return_state=return_state, quiet=quiet, context=context)
+        self.run_command("pip", *args, return_state=return_state, quiet=quiet, context=context)
 
     def install_dependencies(self, quiet=True):
         pip_command = [
@@ -332,7 +340,11 @@ class DepAnalyzer(ABC):  # pylint: disable=too-many-instance-attributes
             self._target.name,
             "--no-deps",
         ]
-        pip_command.extend(self.export_requirements())
+        reqs = self.export_requirements()
+        if not reqs:
+            self.log.warning("No dependencies to install with pip, skipping")
+            return
+        pip_command.extend(reqs)
         self.log.warning("Installing dependencies using pip")
         self._install_pip(*pip_command, quiet=quiet)
         self.log.warning("Installing dependencies done")
@@ -344,14 +356,18 @@ class DepAnalyzer(ABC):  # pylint: disable=too-many-instance-attributes
                 self.log.warning("src/__init__.py exists, installing as package in target")
                 shutil.copytree(src_path, Path(self._target.name) / "src")
             else:
-                self.log.warning("src/__init__.py does not exist, installing files from src directly into target")
+                self.log.warning(
+                    "src/__init__.py does not exist, installing files from src directly into target"
+                )
                 shutil.copytree(src_path, Path(self._target.name), dirs_exist_ok=True)
         elif next(self.project_root.glob("*.py"), None):
             for f in self.project_root.glob("*.py"):
                 self.log.warning("Copying %s to target", f)
                 shutil.copy(f, self._target.name)
         else:
-            self.log.warning("No src/__init__.py or *.py files found, no root program is being installed")
+            self.log.warning(
+                "No src/__init__.py or *.py files found, no root program is being installed"
+            )
 
     def get_layer_files(self):
         target_path = Path(self._target.name)
